<?php // -*- C++ -*-
//
//  star.php3:  Render a gauge-style ht://Dig "star" image
//
//
//  Description:
//
//    This script takes a "star" image file (.gif) and copies it sideways N-times into a
//    rectangle shaped image.  It then gets the hit percentage as provided by htsearch's
//    PERCENT value and cuts the trailing (100-$(PERCENT))% off the image.  Then the hit
//    percentage is rendered into the image using a GD library internal bitmap font.
//
//
//  Parameters:
//
//    font=0,1..5         GD library internal font identifier (or 0 for none)
//
//    r=0..255            RGB red value for rendering the hit percentage
//    g=0..255            RGB green value for rendering the hit percentage
//    b=0..255            RGB blue value for rendering the hit percentage
//
//    ratio=0..100        htsearch hit percentage
//
//    img=/path/to/gif    Alternate image file name, absolute or relative to the script
//
//    stars=1..N          Number of images to put in a row
//
//
//  Example usage:
//
//    Configure ht://Dig to use a template file for formatting the search results which
//    might look like this:
//
//    <DL><DT><STRONG><A HREF="$(URL)">$(TITLE)</A></STRONG> <IMG SRC="/gfx/star.php3?ratio=$(PERCENT)" ALT="($(PERCENT)%)"></DT><DD><DIV ALIGN="justify">$(EXCERPT)<BR><FONT SIZE="-2"><I><A HREF="$(URL)">$(URL)</A></I> Letzte &Auml;nderung: $(MODIFIED), $(SIZE) Bytes</FONT></DIV></DD></DL>
//
//    The above template resembles the original "builtin-long" formatting style, but
//    uses the "star" image bar to display the hit ratio instead of showing a group
//    of "star" images.
//
//
//  Authors:
//
//    Torsten Neuer  <tneuer@inwise.de>
//

if( !isset($stars) ) {    // number of stars to display at 100%
  $stars = 5;
} else if( $stars < 1 ) {
  $stars = 1;
}

if( !isset($font) ) {     // gd library internal font identifier
  $font = 3;
} else if( $font < 0 ) {
  $font = 0;
} else if( $font > 5 ) {
  $font = 5;
}

if( !isset($r) ) {
  $r = 90;
} else if( $r < 0 ) {
  $r = 0;
} else if( $r > 255 ) {
  $r = 255;
}

if( !isset($g) ) {
  $g = 116;
} else if( $g < 0 ) {
  $g = 0;
} else if( $g > 255 ) {
  $g = 255;
}

if( !isset($b) ) {
  $b = 175;
} else if( $b < 0 ) {
  $b = 0;
} else if( $b > 255 ) {
  $b = 255;
}

if( !isset($ratio) ) {     // hit ratio in percent
  $ratio = 100;
} else if( $ratio < 0 ) {
  $ratio = 0;
} else if( $ratio > 100 ) {
  $ratio = 100;
}

if( !isset($img) ) {      // path/name of star image
  $img = "star.gif";
}

function ImagePrintCentered( $image,
			     $s,
			     $font,
			     $color ) {
  $n = strlen($s);
  $fx = ImageFontWidth($font);
  $sx = (int)((ImageSX($image) - ($n * $fx)) / 2);
  $sy = (int)((ImageSY($image) - ImageFontHeight($font)) / 2);
  for( $i=0; $i < $n; ++$i ) {
    ImageChar($image,$font,$sx,$sy,substr($s,$i,1),$color);
    $sx += $fx;
  }
} // ImagePrintCentered()

Header("Content-type:  image/gif");

$star = ImageCreateFromGif($img);

$w = $stars * ($dx = ImageSX($star));
$h = ($dy = ImageSY($star));

$image = ImageCreate($w,$h);

for( $i=0; $i < $stars; ++$i ) {
  ImageCopyResized($image,$star,$i*$dx,0,0,0,$dx,$dy,$dx,$dy);
}

ImageDestroy($star);

ImageFilledRectangle($image,(int)(($ratio * $w) / 100),0,$w,$h,ImageColorAt($image,0,0));

if( $font ) {
  ImagePrintCentered($image,"(".((string)$ratio)."%)",$font,ImageColorAllocate($image,$r,$g,$b));
}

ImageGif($image);
ImageDestroy($image);

?>
